@@ -73,21 +73,21 @@ sub render {
     # Set code 200 if the code has not been set
     $self->set_code(200) unless $self->code;
 
-    # If no content_type is set, then set it based on
-    # the type of $body - JSON or HTML.
-    unless ( $self->content_type ) {
-        ref( $body ) ? $self->json : $self->html;
-    }
+    my $is_json = $self->content_type eq 'application/json';
+    my $guess_json = !$self->content_type && ref($body);
+    my $guess_html = !$self->content_type && !ref($body);
 
     # If the content has been determined as JSON, then encode it
-    if ( $self->content_type eq 'application/json' ) {
+    if ( $is_json || $guess_json ) {
         die "No JSON decoder" unless $self->app->can('json');
         die "Data must be a reference" unless ref($body);
         my $json = $self->app->json;
         $body = $json->encode($body);
         $body = encode($self->app->charset, $body) unless $json->get_utf8;
+        $self->json if $guess_json;
         $self->body( $body );
     } else {
+        $self->html if $guess_html;
         $self->body( encode( $self->app->charset, $body ) );
     }
 
@@ -150,7 +150,7 @@ sub render_500 {
 
     # if render_500 gets blessed object as error stringify it
     $error = ref $error if Scalar::Util::blessed $error;
-    
+
     return $self->set_code(500)->render($error);
 }
 
@@ -158,6 +158,10 @@ sub render_401 {
     $_[0]->render_error( 401, "Unauthorized" );
 }
 
+sub render_403 {
+    $_[0]->render_error( 403, "Forbidden" );
+}
+
 sub redirect {
     my $self = shift;
     $self->rendered(1);
@@ -291,8 +295,6 @@ is does:
 
 If the response code was not previously set, this method will set it to 200.
 
-=cut
-
 =item
 
 If no content-type is previously set, C<render> will set is based on the type of
@@ -302,14 +304,10 @@ C<application/json>, otherwise it will be set to C<text/html>.
     # Will set the content-type to json
     $res->render( { numbers => [ 1, 2, 3 ] } );
 
-=cut
-
 =item
 
 Last, the data will be encoded with the charset specified by the app.
 
-=cut
-
 =back
 
 =head2 set_content_type
@@ -359,7 +357,7 @@ before that.
     use Kelp::Less;
 
     get '/image/:name' => sub {
-        my $content = File::Slurp::read_file("$name.jpg");
+        my $content = Path::Tiny::path("$name.jpg")->slurp_raw;
         res->set_content_type('image/jpeg')->render_binary( $content );
 
         # the same, but probably more effective way (PSGI-server dependent)
